beziers.py
----------

Beziers provides a variety of classes for constructing, manipulating and
drawing Bezier curves and paths. Principally designed for font design
software, it allows you to join, split, offset, and perform many other
operations on paths.

Here is an example session::

    from beziers.point import Point
    from beziers.path import BezierPath
    from beziers.cubicbezier import CubicBezier
    b1 = CubicBezier(
      Point(412.0,500.0), Point(308.0,665.0), Point(163.0,589.0), Point(163.0,504.0)
    )
    b2 = CubicBezier(
      Point(163.0,504.0), Point(163.0,424.0), Point(364.0,321.0), Point(366.0,216.0)
    )
    b3 = CubicBezier(
      Point(366.0,216.0), Point(368.0,94.0), Point(260.0,54.0), Point(124.0,54.0)
    )
    path = BezierPath.fromSegments([b1,b2,b3])
    path.closed = False
    path.addExtremes()
    path.balance()
    path.translate(Point(-100.0,-100.0))

    import matplotlib.pyplot as plt
    fig, ax = plt.subplots()
    path.addExtremes()
    path.plot(ax)
    plt.show()

Full documentation is available at https://simoncozens.github.io/beziers.py/index.html
